@@ -1,5 +1,6 @@
 """pandas smart_open utilities."""
 import logging
+from pathlib import Path
 from typing import Any
 
 import pandas as pd
@@ -10,7 +11,29 @@ from wpdatautil.timeit import Timer
 log = logging.getLogger(__name__)
 
 
-def read_parquet(uri: str, *, df_description: str = "dataframe", **kwargs: Any) -> pd.DataFrame:
+def read_parquet_path(path: Path, *, df_description: str = "dataframe", **kwargs: Any) -> pd.DataFrame:
+    """Return a dataframe read from the given path using `smart_open`.
+
+    :param path: This must be a `pathlib` or `s3path` path.
+    :param df_description: Optional description of dataframe.
+    :param kwargs: These are forwarded to `pd.read_parquet`.
+    """
+    path.parent.mkdir(parents=True, exist_ok=True)
+    return read_parquet_uri(path.as_uri(), df_description=df_description, **kwargs)
+
+
+def write_parquet_path(df: pd.DataFrame, path: Path, *, df_description: str = "dataframe", **kwargs: Any) -> None:
+    """Write the given dataframe to the given path using `smart_open`.
+
+    :param df: Dataframe to write.
+    :param path: This must be a `pathlib` or `s3path` path.
+    :param df_description: Optional description of dataframe.
+    :param kwargs: These are forwarded to `df.to_parquet`.
+    """
+    write_parquet_uri(df, uri=path.as_uri(), df_description=df_description, **kwargs)
+
+
+def read_parquet_uri(uri: str, *, df_description: str = "dataframe", **kwargs: Any) -> pd.DataFrame:
     """Return a dataframe read from the given URI using `smart_open`, thereby supporting both local and S3 URIs.
 
     `kwargs` are forwarded to `pd.read_parquet`.
@@ -28,7 +51,7 @@ def read_parquet(uri: str, *, df_description: str = "dataframe", **kwargs: Any)
     return df
 
 
-def write_parquet(df: pd.DataFrame, uri: str, *, df_description: str = "dataframe", **kwargs: Any) -> None:
+def write_parquet_uri(df: pd.DataFrame, uri: str, *, df_description: str = "dataframe", **kwargs: Any) -> None:
     """Write the given dataframe to the given URI using `smart_open`, thereby supporting both local and S3 URIs.
 
     `kwargs` are forwarded to `df.to_parquet`.
